/*
 *  Filename:  ted.h
 *
 *  Programmer:  Br. David Carlson
 *
 *  Date:  June 23, 1994
 *
 *  This header file is to accompany ted.c and the other source files for the
 *  ted editor.
 */

#define INT32           int
#define INT16           short int
#define INT8            signed char
#define LINE_SIZE       80
#define DEFAULT_PAGES   20
#define LINES_PER_PAGE  50
#define NIL             (-1)
#define OLDFILE         0
#define NEWFILE         1

#define NOERROR         0
#define READERROR       1
#define LENGTHERROR     2
#define ALLOCERROR      3
#define OPENERROR       4

#define ERROR(msg)                        \
   {                                      \
   getch_done();                          \
   display_color(NORMAL);                 \
   display_clear();                       \
   putchar('\n');                         \
   printf(msg);                           \
   putchar('\n');                         \
   exit(1);                               \
   }

#define BLANK_END_OF_LINE printf("                                        \n")


typedef struct line_type
   {
   char info[LINE_SIZE];
   INT8 length;
   INT8 marked;
   INT16 left;
   INT16 right;
   } LINE_TYPE;


typedef struct mark_record
   {
   INT8 num_marks;
   INT16 first_buf_line;
   INT16 second_buf_line;
   INT16 first_file_row;
   INT16 second_file_row;
   } MARK_RECORD;


/*  The following are the function prototypes for the ted project: */

void get_enter(void);

char get_choice(char ch1, char ch2);

INT16 get_index(INT16 row);

void print_line(INT16 index, INT16 row, INT16 col, INT16 num_cols);

void remove_window(INT16 row, INT16 num_rows, INT16 col, INT16 num_cols);

void display_text(INT16 row, INT16 end_row, INT16 index);

void display_text_adjusted(INT16 TargetScreenRow);

INT16 get_buffer_line(void);

void return_buffer_line(INT16 index);

void read_file(FILE *source);

void get_backup_name(char *original_name, char *backup_name);

int buffer_to_file(FILE *destination, INT16 start_line, INT16 end_line);

void buf_initialize(void);

void print_blank_line(void);

void show_row_col(void);

void show_file_col(void);

void show_file_row(void);

void handle_insert(void);

void handle_F1(void);

void handle_F2(void);

void handle_F3(void);

void handle_F4(void);

void handle_F5(void);

void handle_F6(void);

void handle_F7(void);

void handle_F8(void);

void handle_F9(void);

void handle_F10(void);

void handle_backspace(void);

void handle_delete(void);

void handle_tab(void);

void handle_page_up(void);

void handle_page_down(void);

void move_down(INT16 index);

void handle_down_arrow(void);

void handle_up_arrow(void);

void handle_left(void);

void handle_right(void);

void handle_home(void);

void handle_end(void);

void handle_enter(void);

void handle_ctrl_y(void);

void display_info_lines(void);

void handle_ctrl_r(void);

void handle_ctrl_t(void);

void handle_ctrl_b(void);

void handle_ctrl_e(void);

void process_printable(int key);

void process_special(int key);

INT16 get_string(char s[], INT16 max, INT16 row, INT16 start_col);

INT16 match(INT16 *StartLinePtr, INT16 *StartColPtr, INT16 len,
   char target[]);

void MatchDisplay(INT16 start_line, INT16 start_col);

void search(void);

void empty_clipboard(void);

void allocation_error(void);

void unmark(void);

void report_error(INT8 problem);

void syntax_error(void);

void get_screen_num(INT8 *screen_num_ptr);

void help_screen(INT8 screen_num);

